# Contributing to this repository

We welcome your contributions! There are multiple ways to contribute.

## Opening issues

For bugs or enhancement requests, please file a GitHub issue unless it's
security related. When filing a bug remember that the better written the bug is,
the more likely it is to be fixed. If you think you've found a security
vulnerability, do not raise a GitHub issue and follow the instructions in our
[security policy](./SECURITY.md).

When submitting a new Issue for what seems is a bug, please note the versions
(OpenGrok, Tomcat, Universal ctags etc.) you're running and ideally steps to reproduce.

Make sure to add a comment line to the changeset saying which Issue it is is fixing,
e.g. `fixes #XYZ` so that the issue can be automatically closed when the associated
pull request is merged.

## Contributing code

We welcome your code contributions. Before submitting code via a pull request,
you will need to have signed the [Oracle Contributor Agreement][OCA] (OCA) and
your commits need to include the following line using the name and e-mail
address you used to sign the OCA:

```text
Signed-off-by: Your Name <you@example.org>
```

This can be automatically added to pull requests by committing with `--sign-off`
or `-s`, e.g.

```text
git commit --signoff
```

Only pull requests from committers that can be verified as having signed the OCA
can be accepted.

## Pull request process

Each pull request should be accompanied by a comment explaining how the change
was tested, unless unit tests are provided/updated.
Please make every effort to make most of your changes covered by tests. Also,
for more complicated changes, please make any effort to explain the rationale
behind the changes (providing answers to the 'why ?' questions is very important).

Please follow pre-existing coding style.

Asking questions via creating new [discussion](https://github.com/oracle/opengrok/discussions) is fine.

Feel free to add a Copyright line to the source files wehre you made non-trivial changes.

1. Ensure there is an issue created to track and discuss the fix or enhancement
   you intend to submit.
1. Fork this repository.
1. Create a branch in your fork to implement the changes. We recommend using
   the issue number as part of your branch name, e.g. `1234-fixes`.
1. Ensure that any documentation is updated with the changes that are required
   by your change.
1. Ensure that any samples are updated if the base image has been changed.
1. Submit the pull request. *Do not leave the pull request blank*. Explain exactly
   what your changes are meant to do and provide simple steps on how to validate.
   your changes. Ensure that you reference the issue you created as well.
1. We will assign the pull request to 2-3 people for review before it is merged.

## Code of conduct

Follow the [Golden Rule](https://en.wikipedia.org/wiki/Golden_Rule). If you'd
like more specific guidelines, see the [Contributor Covenant Code of Conduct][COC].

[OCA]: https://oca.opensource.oracle.com
[COC]: https://www.contributor-covenant.org/version/1/4/code-of-conduct/
